@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Get XML.
 has xml => (
@@ -38,6 +38,8 @@ Map::Tube::Kharkiv - Interface to the Kharkiv Metro Map.
  use Map::Tube::Kharkiv;
  my $obj = Map::Tube::Kharkiv->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $line = $obj->get_line_by_id($line_id);
+ my $line = $obj->get_line_by_name($line_name);
  my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
@@ -66,6 +68,16 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_line_by_id($line_id)>
+
+ Get line object defined by id.
+ Returns Map::Tube::Line object.
+
+=item C<get_line_by_name($line_name)>
+
+ Get line object defined by name.
+ Returns Map::Tube::Line object.
+
 =item C<get_lines()>
 
  Get lines in metro map.
@@ -166,7 +178,7 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
          'callback_node' => \&node_color_without_label,
          'driver' => 'neato',
          'tube' => $obj,
- ); 
+ );
 
  # Get graph to file.
  $g->graph('Kharkiv.png');
@@ -185,6 +197,30 @@ For more information about Kharkiv Map, click L<here|https://en.wikipedia.org/wi
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Kharkiv;
+
+ # Object.
+ my $obj = Map::Tube::Kharkiv->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Олексіївська лінія
+ # Салтівська лінія
+ # Холодногірсько-Заводська лінія
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -194,31 +230,21 @@ L<namespace::clean>.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Map::Tube::GraphViz>,
-L<Map::Tube::Text::Table>.
+=over
 
-L<Map::Tube::Barcelona>,
-L<Map::Tube::Berlin>,
-L<Map::Tube::Bucharest>,
-L<Map::Tube::Delhi>,
-L<Map::Tube::Dnipropetrovsk>,
-L<Map::Tube::Kazan>,
-L<Map::Tube::Kiev>,
-L<Map::Tube::London>,
-L<Map::Tube::Minsk>,
-L<Map::Tube::Moscow>,
-L<Map::Tube::Novosibirsk>,
-L<Map::Tube::NYC>,
-L<Map::Tube::Prague>,
-L<Map::Tube::SaintPetersburg>,
-L<Map::Tube::Samara>,
-L<Map::Tube::Sofia>,
-L<Map::Tube::Tbilisi>,
-L<Map::Tube::Tokyo>,
-L<Map::Tube::Vienna>,
-L<Map::Tube::Warsaw>,
-L<Map::Tube::Yekaterinburg>.
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=item L<Task::Map::Tube::Metro>
+
+Install the Map::Tube concrete metro modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -232,12 +258,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014 Michal Špaček
+ © 2014-2015 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
